#ifndef MAINWIDGET_H
#define MAINWIDGET_H

#include <qfile.h>

#include "MainWidgetBase.h"
#include "CSchoolData.h"

class CMainWidget : public CMainWidgetBase
{

Q_OBJECT


  public:
   CMainWidget(QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );

  private slots:
    void goodBye();
    void showSchool();
    void showSchoolSet();
    void showJyearList();

  private:
    CSchoolData *m_pschoolData;
    void LoadData();
    void SaveData();
    boolean OpenDataFile(QFile *pfdata);
    boolean isQVGA();
};

#endif

